Update to hplip-3.13.2.

Some parts of the tools are still somewhat WIP; however, thanks to a
donation from linuxfund.org this has been successfully tested on a HP
OfficeJet 7500 e910, using STP discovery over WiFi with automatic PPD
generation. Scanning, printing, cartridge information... working.
This commit is contained in:
ajacoutot 2013-03-08 06:51:46 +00:00
parent d91f0c08da
commit b7e6f6dba1
30 changed files with 356 additions and 279 deletions

View File

@ -1,4 +1,4 @@
# $OpenBSD: Makefile,v 1.67 2013/01/26 19:38:00 ajacoutot Exp $
# $OpenBSD: Makefile,v 1.68 2013/03/08 06:51:46 ajacoutot Exp $
SHARED_ONLY= Yes
@ -8,7 +8,7 @@ COMMENT-hpcups= HP native CUPS driver
COMMENT-libs= HPLIP backend libraries
COMMENT-gui= HPLIP graphical tools
V= 3.12.11
V= 3.13.2
DISTNAME= hplip-${V}
PKGNAME-main= ${DISTNAME}
@ -17,12 +17,6 @@ PKGNAME-hpcups= hpcups-${V}
PKGNAME-libs= hplip-libs-${V}
PKGNAME-gui= hplip-gui-${V}
REVISION-main= 6
REVISION-libs= 0
REVISION-gui= 2
REVISION-hpcups=1
REVISION-hpijs= 0
SHARED_LIBS += hpmud 2.0 # .0.6
SHARED_LIBS += hpip 2.0 # .0.1
@ -161,6 +155,7 @@ pre-configure:
${WRKSRC}/fax/backend/hpfax.py \
${WRKSRC}/base/codes.py \
${WRKSRC}/base/g.py \
${WRKSRC}/base/services.py \
${WRKSRC}/prnt/cups.py \
${WRKSRC}/installer/core_install.py \
${WRKSRC}/doc/upgrading.html \
@ -170,6 +165,7 @@ pre-configure:
${WRKSRC}/base/pkit.py \
${WRKSRC}/prnt/hpijs/foomatic-rip-hplip \
${WRKSRC}/installer/dcheck.py \
${WRKSRC}/installer/pluginhandler.py \
${WRKSRC}/base/magic.py \
${WRKSRC}/base/utils.py \
${WRKSRC}/scan.py \
@ -184,5 +180,6 @@ post-install:
${MODPY_BIN} ${MODPY_LIBDIR}/compileall.py \
${PREFIX}/share/hplip
rm ${PREFIX}/lib/python${MODPY_VERSION}/site-packages/*.la
rm ${PREFIX}/lib/sane/*.la
.include <bsd.port.mk>

View File

@ -1,2 +1,2 @@
SHA256 (hplip-3.12.11.tar.gz) = xbgRZ7IapO5r3z9cEgv6BQ0MeUYI2ovMMuJYAjSRn/o=
SIZE (hplip-3.12.11.tar.gz) = 21932088
SHA256 (hplip-3.13.2.tar.gz) = fe4hwwoVcpshB3E6G3eeoHmCBko44tSTXljm9W1tNZI=
SIZE (hplip-3.13.2.tar.gz) = 21681714

View File

@ -1,12 +1,9 @@
$OpenBSD: patch-Makefile_in,v 1.20 2012/12/10 16:00:11 ajacoutot Exp $
libcompat is needed because hplip uses ftime(3).
--- Makefile.in.orig Tue Nov 20 10:55:50 2012
+++ Makefile.in Mon Dec 10 16:44:44 2012
@@ -4305,16 +4305,16 @@ cups_drv = prnt/drv/hpcups.drv
$OpenBSD: patch-Makefile_in,v 1.21 2013/03/08 06:51:46 ajacoutot Exp $
--- Makefile.in.orig Wed Feb 13 17:39:40 2013
+++ Makefile.in Fri Feb 22 15:48:13 2013
@@ -4313,16 +4313,16 @@ cups_drv = prnt/drv/hpcups.drv
@HPLIP_BUILD_TRUE@@SCAN_BUILD_TRUE@ scan/sane/soaphti.h scan/sane/soapi.h scan/sane/xml.c scan/sane/xml.h scan/sane/ledm.h scan/sane/ledmi.h scan/sane/ledm.c \
@HPLIP_BUILD_TRUE@@SCAN_BUILD_TRUE@ scan/sane/bb_ledm.c scan/sane/http.h scan/sane/http.c scan/sane/sclpml.c scan/sane/sclpml.h
@HPLIP_BUILD_TRUE@@SCAN_BUILD_TRUE@ scan/sane/bb_ledm.c scan/sane/http.h scan/sane/http.c scan/sane/sclpml.c scan/sane/sclpml.h common/utils.c common/utils.h
-@DARWIN_BUILD_FALSE@@HPLIP_BUILD_TRUE@@SCAN_BUILD_TRUE@libsane_hpaio_la_LDFLAGS = -version-info 1:0:0
+@DARWIN_BUILD_FALSE@@HPLIP_BUILD_TRUE@@SCAN_BUILD_TRUE@libsane_hpaio_la_LDFLAGS = -module -avoid-version
@ -24,7 +21,16 @@ libcompat is needed because hplip uses ftime(3).
@HPLIP_BUILD_TRUE@@LIBUSB01_BUILD_TRUE@libhpmud_la_CFLAGS = -DMUDNAME=\"$(MUDNAME)\" -DCONFDIR=\"$(hplip_confdir)\"
@HPLIP_BUILD_TRUE@@LIBUSB01_BUILD_FALSE@libhpmud_la_SOURCES = io/hpmud/hpmud.c io/hpmud/mlc.c io/hpmud/model.c io/hpmud/pml.c \
@HPLIP_BUILD_TRUE@@LIBUSB01_BUILD_FALSE@ io/hpmud/hpmud.h io/hpmud/hpmudi.h io/hpmud/list.h io/hpmud/mlc.h io/hpmud/pml.h io/hpmud/dot4.c \
@@ -4345,7 +4345,7 @@ cups_drv = prnt/drv/hpcups.drv
@@ -4335,7 +4335,7 @@ cups_drv = prnt/drv/hpcups.drv
@HPLIP_BUILD_TRUE@@LIBUSB01_BUILD_TRUE@ common/utils.c common/utils.h
@HPLIP_BUILD_TRUE@libhpmud_la_LDFLAGS = -version-info 0:6:0 -lpthread \
-@HPLIP_BUILD_TRUE@ -ldl $(am__append_2) $(am__append_3) \
+@HPLIP_BUILD_TRUE@ $(am__append_2) $(am__append_3) \
@HPLIP_BUILD_TRUE@ $(am__append_4)
@HPLIP_BUILD_TRUE@libhpip_la_LDFLAGS = -version-info 0:1:0
@HPLIP_BUILD_TRUE@libhpip_la_LIBADD = -lm
@@ -4348,7 +4348,7 @@ cups_drv = prnt/drv/hpcups.drv
# hp-mkuri.
@HPLIP_BUILD_TRUE@hp_mkuridir = $(bindir)
@HPLIP_BUILD_TRUE@hp_mkuri_SOURCES = io/hpmud/hp-mkuri.c
@ -33,7 +39,7 @@ libcompat is needed because hplip uses ftime(3).
@HPLIP_BUILD_TRUE@hp_mkuri_CFLAGS = -DCONFDIR=\"$(hplip_confdir)\"
# cron files
@@ -4378,7 +4378,7 @@ cups_drv = prnt/drv/hpcups.drv
@@ -4381,7 +4381,7 @@ cups_drv = prnt/drv/hpcups.drv
@HPLIP_BUILD_TRUE@pstotiff_SCRIPTS = fax/filters/pstotiff
# hplip.state
@ -42,7 +48,7 @@ libcompat is needed because hplip uses ftime(3).
@HPLIP_BUILD_TRUE@dist_hplip_state_DATA =
#dist_hplip_state_DATA = hplip.state
@@ -4504,7 +4504,7 @@ cups_drv = prnt/drv/hpcups.drv
@@ -4510,7 +4510,7 @@ cups_drv = prnt/drv/hpcups.drv
@FULL_BUILD_TRUE@@HPLIP_BUILD_TRUE@hpmudext_la_LDFLAGS = -module -avoid-version
@FULL_BUILD_TRUE@@HPLIP_BUILD_TRUE@hpmudext_la_SOURCES = io/mudext/hpmudext.c
@FULL_BUILD_TRUE@@HPLIP_BUILD_TRUE@hpmudext_la_LIBADD = libhpmud.la
@ -51,7 +57,7 @@ libcompat is needed because hplip uses ftime(3).
@FULL_BUILD_TRUE@@HPLIP_BUILD_TRUE@@LIBUSB01_BUILD_TRUE@hpmudext_la_CFLAGS = -I$(PYTHONINCLUDEDIR)
# ui (qt3)
@@ -4560,7 +4560,7 @@ cups_drv = prnt/drv/hpcups.drv
@@ -4566,7 +4566,7 @@ cups_drv = prnt/drv/hpcups.drv
@FULL_BUILD_TRUE@@HPLIP_BUILD_TRUE@hppgsz_SOURCES = prnt/hpijs/PrinterProperties.cpp prnt/hpijs/PrinterProperties.h prnt/hpijs/bug.h
@FULL_BUILD_TRUE@@HPLIP_BUILD_TRUE@hppgsz_CXXFLAGS = $(libapdk_la_CXXFLAGS)
@FULL_BUILD_TRUE@@HPLIP_BUILD_TRUE@hppgsz_CFLAGS = $(libapdk_la_CFLAGS)
@ -60,7 +66,7 @@ libcompat is needed because hplip uses ftime(3).
# hplip.desktop
@FULL_BUILD_TRUE@@GUI_BUILD_TRUE@@HPLIP_BUILD_TRUE@hplip_desktopdir = $(icondir)
@@ -4631,8 +4631,8 @@ libapdk_la_CFLAGS = $(libapdk_la_CXXFLAGS) -Iprnt/hpij
@@ -4639,8 +4639,8 @@ libapdk_la_CFLAGS = $(libapdk_la_CXXFLAGS) -Iprnt/hpij
@HPIJS_INSTALL_TRUE@hpijs_CXXFLAGS = $(libapdk_la_CXXFLAGS)
@HPIJS_INSTALL_TRUE@hpijs_CFLAGS = $(libapdk_la_CFLAGS)
@ -71,16 +77,16 @@ libcompat is needed because hplip uses ftime(3).
# hpcups
#if NEW_HPCUPS
@@ -4671,7 +4671,7 @@ libapdk_la_CFLAGS = $(libapdk_la_CXXFLAGS) -Iprnt/hpij
@HPCUPS_INSTALL_TRUE@ prnt/hpcups/Hbpl1.cpp prnt/hpcups/Hbpl1.h prnt/hpcups/Hbpl1_Wrapper.h
@@ -4680,7 +4680,7 @@ libapdk_la_CFLAGS = $(libapdk_la_CXXFLAGS) -Iprnt/hpij
@HPCUPS_INSTALL_TRUE@ common/utils.c common/utils.h
@HPCUPS_INSTALL_TRUE@hpcups_CXXFLAGS = $(APDK_ENDIAN_FLAG) $(DBUS_CFLAGS)
-@HPCUPS_INSTALL_TRUE@hpcups_LDADD = -ljpeg -ldl -lcups -lcupsimage $(DBUS_LIBS)
+@HPCUPS_INSTALL_TRUE@hpcups_LDADD = -ljpeg -lcups -lcupsimage -lcompat $(DBUS_LIBS)
+@HPCUPS_INSTALL_TRUE@hpcups_LDADD = -ljpeg -lcups -lcupsimage $(DBUS_LIBS)
#else
#hpcupsdir = $(cupsfilterdir)
#hpcups_PROGRAMS = hpcups
@@ -4679,9 +4679,9 @@ libapdk_la_CFLAGS = $(libapdk_la_CXXFLAGS) -Iprnt/hpij
@@ -4688,15 +4688,15 @@ libapdk_la_CFLAGS = $(libapdk_la_CXXFLAGS) -Iprnt/hpij
#hpcups_CXXFLAGS = $(libapdk_la_CXXFLAGS)
#hpcups_CFLAGS = $(libapdk_la_CFLAGS)
#if HPCUPS_ONLY_BUILD
@ -92,22 +98,29 @@ libcompat is needed because hplip uses ftime(3).
#endif #HPCUPS_ONLY_BUILD
#endif # NEW_HPCUPS
# hpcupsfax
@@ -8652,11 +8652,11 @@ install-data-am: install-cupsdrv2DATA install-cupsdrvD
@FAX_BUILD_TRUE@@HPCUPS_INSTALL_TRUE@@HPCUPS_ONLY_BUILD_FALSE@hpcupsfaxdir = $(cupsfilterdir)
@FAX_BUILD_TRUE@@HPCUPS_INSTALL_TRUE@@HPCUPS_ONLY_BUILD_FALSE@hpcupsfax_SOURCES = prnt/hpijs/hpcupsfax.cpp prnt/hpijs/hpcupsfax.h common/utils.h common/utils.c
-@FAX_BUILD_TRUE@@HPCUPS_INSTALL_TRUE@@HPCUPS_ONLY_BUILD_FALSE@hpcupsfax_LDADD = libhpip.la -lcups -lcupsimage -ldl
+@FAX_BUILD_TRUE@@HPCUPS_INSTALL_TRUE@@HPCUPS_ONLY_BUILD_FALSE@hpcupsfax_LDADD = libhpip.la -lcups -lcupsimage
# PPDs
ppddir = $(hpppddir)
@@ -8735,11 +8735,11 @@ install-data-am: install-cupsdrv2DATA install-cupsdrvD
install-dist_cacSCRIPTS install-dist_cmdSCRIPTS \
install-dist_copierDATA install-dist_cronDATA \
install-dist_faxDATA install-dist_fax_filtersDATA \
- install-dist_finSCRIPTS install-dist_halpreDATA \
+ install-dist_finSCRIPTS \
install-dist_hpcupsfaxppdDATA install-dist_hpfaxSCRIPTS \
install-dist_hpijsfaxppdDATA install-dist_hplipSCRIPTS \
- install-dist_hplip_LogDATA install-dist_hplip_stateDATA \
- install-dist_hplip_tmpDATA install-dist_images_128x128DATA \
install-dist_homeDATA install-dist_hpcupsfaxppdDATA \
install-dist_hpfaxSCRIPTS install-dist_hpijsfaxppdDATA \
- install-dist_hplipSCRIPTS install-dist_hplip_LogDATA \
- install-dist_hplip_stateDATA install-dist_hplip_tmpDATA \
+ install-dist_hplipSCRIPTS \
+ install-dist_hplip_stateDATA \
+ install-dist_images_128x128DATA \
install-dist_images_16x16DATA install-dist_images_24x24DATA \
install-dist_images_256x256DATA install-dist_images_32x32DATA \
install-dist_images_64x64DATA install-dist_images_devicesDATA \
@@ -8668,7 +8668,7 @@ install-data-am: install-cupsdrv2DATA install-cupsdrvD
install-dist_images_128x128DATA install-dist_images_16x16DATA \
install-dist_images_24x24DATA install-dist_images_256x256DATA \
install-dist_images_32x32DATA install-dist_images_64x64DATA \
@@ -8752,7 +8752,7 @@ install-data-am: install-cupsdrv2DATA install-cupsdrvD
install-dist_policykit_dbus_shareDATA \
install-dist_policykit_policyDATA install-dist_postscriptDATA \
install-dist_ppdDATA install-dist_prntDATA \
@ -116,8 +129,8 @@ libcompat is needed because hplip uses ftime(3).
install-dist_scanDATA install-dist_ui4DATA install-dist_uiDATA \
install-dist_unrelDATA install-dist_www0DATA \
install-dist_www3DATA install-dist_www4DATA install-docDATA \
@@ -8893,17 +8893,6 @@ install-dist_cronDATA:$(dist_cron_DATA)
done
@@ -8979,17 +8979,6 @@ install-dist_cronDATA:$(dist_cron_DATA)
done
install-data-hook:
-# If scanner build, add hpaio entry to sane dll.conf.

View File

@ -1,7 +1,7 @@
$OpenBSD: patch-base_g_py,v 1.5 2012/10/12 21:56:07 ajacoutot Exp $
--- base/g.py.orig Wed Oct 10 08:14:21 2012
+++ base/g.py Fri Oct 12 23:40:53 2012
@@ -144,15 +144,15 @@ class ConfigBase(object):
$OpenBSD: patch-base_g_py,v 1.6 2013/03/08 06:51:46 ajacoutot Exp $
--- base/g.py.orig Wed Feb 13 17:38:51 2013
+++ base/g.py Fri Feb 22 15:13:09 2013
@@ -145,16 +145,16 @@ class ConfigBase(object):
class SysConfig(ConfigBase):
def __init__(self):
@ -13,16 +13,17 @@ $OpenBSD: patch-base_g_py,v 1.5 2012/10/12 21:56:07 ajacoutot Exp $
def __init__(self):
- if not os.path.exists('/var/lib/hp/') and os.geteuid() == 0:
- os.makedirs('/var/lib/hp/')
- os.system('chmod 644 /var/lib/hp/')
- ConfigBase.__init__(self, '/var/lib/hp/hplip.state')
- cmd = 'chmod 644 /var/lib/hp/'
+ if not os.path.exists('/var/db/hp/') and os.geteuid() == 0:
+ os.makedirs('/var/db/hp/')
+ os.system('chmod 644 /var/db/hp/')
+ cmd = 'chmod 644 /var/db/hp/'
os_utils.execute(cmd)
- ConfigBase.__init__(self, '/var/lib/hp/hplip.state')
+ ConfigBase.__init__(self, '/var/db/hp/hplip.state')
class UserConfig(ConfigBase):
@@ -250,9 +250,9 @@ prop.max_message_len = 8192
@@ -252,9 +252,9 @@ prop.max_message_len = 8192
prop.max_message_read = 65536
prop.read_timeout = 90

View File

@ -0,0 +1,11 @@
$OpenBSD: patch-base_password_py,v 1.1 2013/03/08 06:51:46 ajacoutot Exp $
--- base/password.py.orig Fri Feb 22 17:51:28 2013
+++ base/password.py Fri Feb 22 17:52:02 2013
@@ -53,6 +53,7 @@ AUTH_TYPES ={'mepis':'su',
'gos':'sudo',
'boss':'su',
'lfs':'su',
+ 'openbsd':'su',
}

View File

@ -1,18 +1,7 @@
$OpenBSD: patch-base_pkit_py,v 1.7 2013/01/20 10:43:00 ajacoutot Exp $
--- base/pkit.py.orig Tue Nov 20 10:55:15 2012
+++ base/pkit.py Sun Jan 20 10:13:19 2013
@@ -346,8 +346,8 @@ def copyPluginFiles(src_dir):
SANELIBDIR = '/usr/lib64/sane'
LIBDIR = '/usr/lib64'
else:
- SANELIBDIR = '/usr/lib/sane'
- LIBDIR = '/usr/lib'
+ SANELIBDIR = '${LOCALBASE}/lib/sane'
+ LIBDIR = '${LOCALBASE}/lib'
copies = []
@@ -492,7 +492,7 @@ def run_plugin_command(required=True, plugin_reason=PL
$OpenBSD: patch-base_pkit_py,v 1.8 2013/03/08 06:51:46 ajacoutot Exp $
--- base/pkit.py.orig Wed Feb 13 17:38:51 2013
+++ base/pkit.py Fri Feb 22 15:05:18 2013
@@ -363,7 +363,7 @@ def run_plugin_command(required=True, plugin_reason=PL
if utils.which("hp-plugin"):
p_path="hp-plugin"
else:
@ -20,8 +9,8 @@ $OpenBSD: patch-base_pkit_py,v 1.7 2013/01/20 10:43:00 ajacoutot Exp $
+ p_path="${MODPY_BIN} ./plugin.py"
if 'gksu' in su_sudo:
cmd = su_sudo % ("%s -u %s --reason %s" % (p_path, req, plugin_reason))
@@ -511,7 +511,7 @@ def run_plugin_command(required=True, plugin_reason=PL
cmd = passwordObj.getAuthCmd() % ("%s -u %s --reason %s" % (p_path, req, plugin_reason))
@@ -380,7 +380,7 @@ def run_plugin_command(required=True, plugin_reason=PL
def policykit_version():

View File

@ -1,6 +1,6 @@
$OpenBSD: patch-base_queues_py,v 1.1 2013/01/26 12:25:54 ajacoutot Exp $
--- base/queues.py.orig Sat Jan 26 13:18:00 2013
+++ base/queues.py Sat Jan 26 13:17:47 2013
$OpenBSD: patch-base_queues_py,v 1.2 2013/03/08 06:51:46 ajacoutot Exp $
--- base/services.py.orig Fri Feb 22 15:29:34 2013
+++ base/services.py Fri Feb 22 15:33:02 2013
@@ -67,6 +67,9 @@ def restart_cups():
elif os.path.exists('/etc/init.d/cupsys'):
return '/etc/init.d/cupsys restart'
+ elif os.path.exists('${RCDIR}/cupsd'):
+ return '${RCDIR}/cupsd restart'
+
else:
return 'killall -HUP cupsd'
@@ -186,6 +189,22 @@ def start_service( service_name, passwordObj):
if sts ==0:
if 'stop' in out or 'inactive' in out:
cmd_start = passwordObj.getAuthCmd()%('/etc/init.d/%s start'%service_name)
+ log.debug("cmd_start=%s"%cmd_start)
+ sts,out = utils.run(cmd_start, passwordObj)
+ if sts ==0:
+ ret_Val = True
+ else:
+ ret_Val = True
+ else:
+ log.error("Fail to start %s service, please start %s service manually."%(service_name,service_name))
+
+ elif os.path.exists('${RCDIR}/%s'%service_name):
+ cmd_status = passwordObj.getAuthCmd()%('${RCDIR}/%s check'%service_name)
+ log.debug(cmd_status)
+ sts,out = utils.run(cmd_status, passwordObj)
+ if sts ==0:
+ if 'stop' in out or 'inactive' in out:
+ cmd_start = passwordObj.getAuthCmd()%('${RCDIR}/%s start'%service_name)
log.debug("cmd_start=%s"%cmd_start)
sts,out = utils.run(cmd_start, passwordObj)
if sts ==0:

View File

@ -1,7 +1,7 @@
$OpenBSD: patch-base_utils_py,v 1.7 2012/10/12 21:56:07 ajacoutot Exp $
--- base/utils.py.orig Wed Oct 10 08:14:21 2012
+++ base/utils.py Fri Oct 12 23:39:47 2012
@@ -525,7 +525,7 @@ class UserSettings(object): # Note: Deprecated after 2
$OpenBSD: patch-base_utils_py,v 1.8 2013/03/08 06:51:46 ajacoutot Exp $
--- base/utils.py.orig Wed Feb 13 17:38:51 2013
+++ base/utils.py Fri Feb 22 17:54:51 2013
@@ -569,7 +569,7 @@ class UserSettings(object): # Note: Deprecated after 2
if len(path):
self.cmd_pcard = 'hp-unload -d %DEVICE_URI%'
else:
@ -10,7 +10,7 @@ $OpenBSD: patch-base_utils_py,v 1.7 2012/10/12 21:56:07 ajacoutot Exp $
# Copy
path = which('hp-makecopies')
@@ -533,7 +533,7 @@ class UserSettings(object): # Note: Deprecated after 2
@@ -577,7 +577,7 @@ class UserSettings(object): # Note: Deprecated after 2
if len(path):
self.cmd_copy = 'hp-makecopies -d %DEVICE_URI%'
else:
@ -19,7 +19,7 @@ $OpenBSD: patch-base_utils_py,v 1.7 2012/10/12 21:56:07 ajacoutot Exp $
# Fax
path = which('hp-sendfax')
@@ -541,7 +541,7 @@ class UserSettings(object): # Note: Deprecated after 2
@@ -585,7 +585,7 @@ class UserSettings(object): # Note: Deprecated after 2
if len(path):
self.cmd_fax = 'hp-sendfax -d %FAX_URI%'
else:
@ -28,7 +28,7 @@ $OpenBSD: patch-base_utils_py,v 1.7 2012/10/12 21:56:07 ajacoutot Exp $
# Fax Address Book
path = which('hp-fab')
@@ -549,7 +549,7 @@ class UserSettings(object): # Note: Deprecated after 2
@@ -593,7 +593,7 @@ class UserSettings(object): # Note: Deprecated after 2
if len(path):
self.cmd_fab = 'hp-fab'
else:
@ -37,15 +37,25 @@ $OpenBSD: patch-base_utils_py,v 1.7 2012/10/12 21:56:07 ajacoutot Exp $
def load(self):
self.loadDefaults()
@@ -881,9 +881,8 @@ def all(S,f=lambda x:x):
@@ -925,10 +925,9 @@ def all(S,f=lambda x:x):
if not f(x): return False
return True
-BROWSERS = ['firefox', 'mozilla', 'konqueror', 'epiphany', 'skipstone'] # in preferred order
-BROWSER_OPTS = {'firefox': '-new-tab', 'mozilla': '', 'konqueror': '', 'epiphany': '--new-tab', 'skipstone': ''}
-
+BROWSERS = ['xdg-open']
+BROWSER_OPTS = {'xdg-open' : ''}
-
def find_browser():
if platform_avail and platform.system() == 'Darwin':
return "open"
@@ -2059,7 +2058,7 @@ def check_user_groups(required_grps_str, avl_grps):
grps =re.sub(r'\s', '', str(grps))
exp_grp_list = grps.split(',')
else:
- exp_grp_list.append('lp')
+ exp_grp_list.append('_cups')
log.debug("Requied groups list =[%s]"%exp_grp_list)

View File

@ -1,7 +1,7 @@
$OpenBSD: patch-check_py,v 1.10 2013/01/26 12:25:54 ajacoutot Exp $
--- check.py.orig Tue Nov 20 10:55:15 2012
+++ check.py Sat Jan 26 13:15:17 2013
@@ -115,9 +115,9 @@ def get_comment(package, Inst_status, installed_ver):
$OpenBSD: patch-check_py,v 1.11 2013/03/08 06:51:46 ajacoutot Exp $
--- check.py.orig Wed Feb 13 17:38:51 2013
+++ check.py Fri Feb 22 17:02:30 2013
@@ -142,9 +142,9 @@ def get_comment(package, Inst_status, installed_ver):
comment = "Python Programming is not supported if version is lessthan 2.2"
elif package == 'hpaio':
if Inst_status == 'OK':
@ -13,16 +13,7 @@ $OpenBSD: patch-check_py,v 1.10 2013/01/26 12:25:54 ajacoutot Exp $
elif package == 'cupsext' or package == 'pcardext' or package == 'hpmudext':
if Inst_status != 'OK':
comment = "'Not Found or Failed to load, Please reinstall HPLIP'"
@@ -218,7 +218,7 @@ def check_user_groups(str_grp, avl_grps):
grps =re.sub(r'\s', '', str(grps))
exp_grp_list = grps.split(',')
else:
- exp_grp_list.append('lp')
+ exp_grp_list.append('_cups')
log.debug("Requied groups list =[%s]"%exp_grp_list)
@@ -337,7 +337,7 @@ class DependenciesCheck(CoreInstall):
@@ -217,7 +217,7 @@ class DependenciesCheck(CoreInstall):
'pyqt4': (True, ['gui_qt4'], "Python-Qt4", self.check_pyqt4,'4.0','FUNC#get_pyQt4_version'), # PyQt 4.x )
'pyqt4-dbus' : (True, ['gui_qt4'], "PyQt4-DBUS", self.check_pyqt4_dbus,'4.0','FUNC#get_pyQt4_version'),
'pyqt': (True, ['gui_qt'], "Python-Qt", self.check_pyqt,'2.3','FUNC#get_pyQt_version'),
@ -31,7 +22,7 @@ $OpenBSD: patch-check_py,v 1.10 2013/01/26 12:25:54 ajacoutot Exp $
'python-notify' : (False, ['gui_qt4'], "Desktop-notifications", self.check_pynotify,'-','python-notify --version'), # Optional for libnotify style popups from hp-systray
'python-xml' : (True, ['base'], "Python-XML-Lib", self.check_python_xml,'-','FUNC#get_python_xml_version'),
'pil': (False, ['scan'], "Python-Image-Lib", self.check_pil,'-','FUNC#get_pil_version'), #required for commandline scanning with hp-scan
@@ -348,7 +348,7 @@ class DependenciesCheck(CoreInstall):
@@ -228,7 +228,7 @@ class DependenciesCheck(CoreInstall):
COMPILEDEP:
{ 'gcc' : (True, ['base'], 'gcc-Compiler', self.check_gcc, '-','gcc --version'),
'libtool': (True, ['base'], "Build-tools", self.check_libtool,'-','libtool --version'),
@ -40,36 +31,48 @@ $OpenBSD: patch-check_py,v 1.10 2013/01/26 12:25:54 ajacoutot Exp $
},
PYEXT:
{ 'cupsext' : (True, ['base'], 'CUPS-Extension', self.check_cupsext,'-','FUNC#get_HPLIP_version'),
@@ -533,9 +533,9 @@ try:
@@ -310,9 +310,9 @@ class DependenciesCheck(CoreInstall):
%(self.distro_name, self.distro_version, self.distro_name, supported_distro_vrs)))
tui.header("SYSTEM INFO")
- Sts, Kernel_info =utils.run("uname -r -v -o")
+ Sts, Kernel_info =utils.run("uname -r -v -s")
Sts, Host_info =utils.run("uname -n")
- Sts, Proc_info =utils.run("uname -r -v -o")
+ Sts, Proc_info =utils.run("uname -r -v -s")
log.info(" Kernel: %s Host: %s Proc: %s Distribution: %s %s"\
%(Kernel_info,Host_info,Proc_info,self.distro_name, self.distro_version))
@@ -328,9 +328,9 @@ class DependenciesCheck(CoreInstall):
log.warn("HPLIP-Installation: Auto installation is not supported for %s distro %s version " %(self.distro_name, self.distro_version))
log.info()
- log.info(log.bold("Current contents of '/etc/hp/hplip.conf' file:"))
+ log.info(log.bold("Current contents of '${SYSCONFDIR}/hp/hplip.conf' file:"))
try:
- output = file('/etc/hp/hplip.conf', 'r').read()
+ output = file('${SYSCONFDIR}/hp/hplip.conf', 'r').read()
except (IOError, OSError), e:
log.error("Could not access file: %s. Check HPLIP installation." % e.strerror)
num_errors += 1
@@ -543,9 +543,9 @@ try:
log.info(output)
log.info()
- log.info(log.bold("Current contents of '/etc/hp/hplip.conf' file:"))
+ log.info(log.bold("Current contents of '${SYSCONFDIR}/hp/hplip.conf' file:"))
try:
- output = file('/etc/hp/hplip.conf', 'r').read()
+ output = file('${SYSCONFDIR}/hp/hplip.conf', 'r').read()
except (IOError, OSError), e:
log.error("Could not access file: %s. Check HPLIP installation." % e.strerror)
self.num_errors += 1
@@ -338,9 +338,9 @@ class DependenciesCheck(CoreInstall):
log.info(output)
log.info()
- log.info(log.bold("Current contents of '/var/lib/hp/hplip.state' file:"))
+ log.info(log.bold("Current contents of '/var/db/hp/hplip.state' file:"))
try:
- output = file(os.path.expanduser('/var/lib/hp/hplip.state'), 'r').read()
+ output = file(os.path.expanduser('/var/db/hp/hplip.state'), 'r').read()
except (IOError, OSError), e:
log.info("Plugins are not installed. Could not access file: %s" % e.strerror)
else:
@@ -752,7 +752,7 @@ try:
#log.info("Installed in HPLIP?: %s" % x)
log.info("Device URI: %s" % device_uri)
log.info()
- log.info(log.bold("Current contents of '/var/lib/hp/hplip.state' file:"))
+ log.info(log.bold("Current contents of '/var/db/hp/hplip.state' file:"))
try:
- output = file(os.path.expanduser('/var/lib/hp/hplip.state'), 'r').read()
+ output = file(os.path.expanduser('/var/db/hp/hplip.state'), 'r').read()
except (IOError, OSError), e:
log.info("Plugins are not installed. Could not access file: %s" % e.strerror)
else:
@@ -538,7 +538,7 @@ class DependenciesCheck(CoreInstall):
#log.info("Installed in HPLIP?: %s" % x)
log.info("Device URI: %s" % device_uri)
- ppd = os.path.join('/etc/cups/ppd', printer_name + '.ppd')
+ ppd = os.path.join('${SYSCONFDIR}/cups/ppd', printer_name + '.ppd')
- ppd = os.path.join('/etc/cups/ppd', printer_name + '.ppd')
+ ppd = os.path.join('${SYSCONFDIR}/cups/ppd', printer_name + '.ppd')
if os.path.exists(ppd):
log.info("PPD: %s" % ppd)
if os.path.exists(ppd):
log.info("PPD: %s" % ppd)

View File

@ -0,0 +1,20 @@
$OpenBSD: patch-common_utils_c,v 1.1 2013/03/08 06:51:46 ajacoutot Exp $
implicit declaration of function 'mkstemp'
--- common/utils.c.orig Fri Feb 22 18:00:50 2013
+++ common/utils.c Fri Feb 22 18:01:05 2013
@@ -1,5 +1,6 @@
#include "utils.h"
#include "string.h"
+#include <stdlib.h>
#include <dlfcn.h>
#include <sys/stat.h>
#include <errno.h>
@@ -259,4 +260,4 @@ int createTempFile(char* szFileName, FILE** pFilePtr)
}
return iFD;
-}
\ No newline at end of file
+}

View File

@ -1,7 +1,7 @@
$OpenBSD: patch-installer_core_install_py,v 1.12 2013/01/20 07:32:08 ajacoutot Exp $
--- installer/core_install.py.orig Tue Nov 20 10:51:37 2012
+++ installer/core_install.py Sat Jan 19 10:58:47 2013
@@ -218,7 +218,7 @@ class CoreInstall(object):
$OpenBSD: patch-installer_core_install_py,v 1.13 2013/03/08 06:51:46 ajacoutot Exp $
--- installer/core_install.py.orig Wed Feb 13 17:35:01 2013
+++ installer/core_install.py Fri Feb 22 15:10:42 2013
@@ -172,7 +172,7 @@ class CoreInstall(object):
self.endian = utils.LITTLE_ENDIAN
self.distro, self.distro_name, self.distro_version = DISTRO_UNKNOWN, '', DISTRO_VER_UNKNOWN
self.distro_version_supported = False
@ -10,7 +10,7 @@ $OpenBSD: patch-installer_core_install_py,v 1.12 2013/01/20 07:32:08 ajacoutot E
self.hplip_present = False
self.have_dependencies = {}
self.native_cups = True
@@ -876,7 +876,7 @@ class CoreInstall(object):
@@ -746,7 +746,7 @@ class CoreInstall(object):
def check_make(self):
@ -19,7 +19,7 @@ $OpenBSD: patch-installer_core_install_py,v 1.12 2013/01/20 07:32:08 ajacoutot E
def check_libusb(self):
@@ -885,14 +885,14 @@ class CoreInstall(object):
@@ -755,14 +755,14 @@ class CoreInstall(object):
if not check_lib('libusb'):
return False
if self.distro_name != "rhel":
@ -36,7 +36,7 @@ $OpenBSD: patch-installer_core_install_py,v 1.12 2013/01/20 07:32:08 ajacoutot E
else:
return True
@@ -902,11 +902,10 @@ class CoreInstall(object):
@@ -772,11 +772,10 @@ class CoreInstall(object):
def check_libcrypto(self):
@ -50,7 +50,7 @@ $OpenBSD: patch-installer_core_install_py,v 1.12 2013/01/20 07:32:08 ajacoutot E
def check_libnetsnmp(self):
@@ -958,7 +957,7 @@ class CoreInstall(object):
@@ -828,7 +827,7 @@ class CoreInstall(object):
def check_sane_devel(self):
@ -59,7 +59,7 @@ $OpenBSD: patch-installer_core_install_py,v 1.12 2013/01/20 07:32:08 ajacoutot E
def check_xsane(self):
@@ -1059,9 +1058,8 @@ class CoreInstall(object):
@@ -929,9 +928,8 @@ class CoreInstall(object):
def check_dbus(self):
@ -71,7 +71,7 @@ $OpenBSD: patch-installer_core_install_py,v 1.12 2013/01/20 07:32:08 ajacoutot E
def check_cups_devel(self):
@@ -1079,17 +1077,17 @@ class CoreInstall(object):
@@ -949,12 +947,12 @@ class CoreInstall(object):
def check_cups_image(self):
@ -85,16 +85,8 @@ $OpenBSD: patch-installer_core_install_py,v 1.12 2013/01/20 07:32:08 ajacoutot E
+ return locate_files('hplip.conf', '${SYSCONFDIR}/hp')
- def check_hpssd(self):
- log.debug("Checking for hpssd...")
- return check_ps(['hpssd'])
+# def check_hpssd(self):
+# log.debug("Checking for hpssd...")
+# return check_ps(['hpssd'])
def check_libtool(self):
@@ -1109,14 +1107,14 @@ class CoreInstall(object):
@@ -974,9 +972,9 @@ class CoreInstall(object):
def check_cupsddk(self):
log.debug("Checking for cups-ddk...")
# TODO: Compute these paths some way or another...
@ -107,38 +99,21 @@ $OpenBSD: patch-installer_core_install_py,v 1.12 2013/01/20 07:32:08 ajacoutot E
def check_policykit(self):
log.debug("Checking for PolicyKit...")
- return (check_file('PolicyKit.conf', "/etc/PolicyKit") and check_file('org.gnome.PolicyKit.AuthorizationManager.service', "/usr/share/dbus-1/services")) or (check_file('50-localauthority.conf', "/etc/polkit-1/localauthority.conf.d") and check_file('org.freedesktop.PolicyKit1.service', "/usr/share/dbus-1/system-services"))
+ return (check_file('PolicyKit.conf', "/etc/PolicyKit") and check_file('org.gnome.PolicyKit.AuthorizationManager.service', "/usr/share/dbus-1/services")) or (check_file('org.freedesktop.PolicyKit1.service', "${LOCALBASE}/share/dbus-1/system-services"))
def check_cupsext(self):
log.debug("Checking 'cupsext' CUPS extension...")
@@ -1540,7 +1538,7 @@ class CoreInstall(object):
cmd = self.su_sudo() % '/etc/init.d/cupsys restart'
@@ -985,7 +983,7 @@ class CoreInstall(object):
return True
elif check_file('50-localauthority.conf', "/etc/polkit-1/localauthority.conf.d") and check_file('org.freedesktop.PolicyKit1.service', "/usr/share/dbus-1/system-services"):
return True
- elif check_file('org.freedesktop.PolicyKit1.conf','/etc/dbus-1/system.d'):
+ elif check_file('org.freedesktop.PolicyKit1.conf','${SYSCONFDIR}/dbus-1/system.d'):
return True
else:
- cmd = self.su_sudo() % 'killall -HUP cupsd'
+ cmd = self.su_sudo() % 'pkill -HUP cupsd'
self.run(cmd)
@@ -1883,7 +1881,7 @@ class CoreInstall(object):
return False
@@ -1558,7 +1556,7 @@ class CoreInstall(object):
def pre_build(self,distro_ver=None):
cmds = []
if self.get_distro_ver_data('fix_ppd_symlink', False,distro_ver):
- cmds.append(self.su_sudo() % 'python ./installer/fix_symlink.py')
+ cmds.append(self.su_sudo() % '${MODPY_BIN} ./installer/fix_symlink.py')
- cmds.append(self.passwordObj.getAuthCmd() % 'python ./installer/fix_symlink.py')
+ cmds.append(self.passwordObj.getAuthCmd() % '${MODPY_BIN} ./installer/fix_symlink.py')
return cmds
@@ -2058,8 +2056,8 @@ class CoreInstall(object):
url = "http://hplip.sf.net/plugin.conf"
home = sys_conf.get('dirs', 'home')
- if os.path.exists('/etc/hp/plugin.conf'):
- url = "file:///etc/hp/plugin.conf"
+ if os.path.exists('${SYSCONFDIR}/hp/plugin.conf'):
+ url = "file://${SYSCONFDIR}/hp/plugin.conf"
elif os.path.exists(os.path.join(home, 'plugin.conf')):
url = "file://" + os.path.join(home, 'plugin.conf')

View File

@ -1,7 +1,7 @@
$OpenBSD: patch-installer_dcheck_py,v 1.5 2013/01/20 07:32:08 ajacoutot Exp $
--- installer/dcheck.py.orig Tue Nov 20 10:51:37 2012
+++ installer/dcheck.py Sat Jan 19 11:30:37 2013
@@ -44,7 +44,7 @@ mod_output = ''
$OpenBSD: patch-installer_dcheck_py,v 1.6 2013/03/08 06:51:46 ajacoutot Exp $
--- installer/dcheck.py.orig Wed Feb 13 17:35:01 2013
+++ installer/dcheck.py Fri Feb 22 15:56:24 2013
@@ -46,7 +46,7 @@ mod_output = ''
def update_ld_output():
# For library checks
global ld_output
@ -10,7 +10,7 @@ $OpenBSD: patch-installer_dcheck_py,v 1.5 2013/01/20 07:32:08 ajacoutot Exp $
if status != 0:
log.debug("ldconfig failed.")
@@ -99,7 +99,7 @@ def check_lib(lib, min_ver=0):
@@ -101,7 +101,7 @@ def check_lib(lib, min_ver=0):
log.debug("Not found.")
return False
@ -19,15 +19,15 @@ $OpenBSD: patch-installer_dcheck_py,v 1.5 2013/01/20 07:32:08 ajacoutot Exp $
log.debug("Searching for file '%s' in '%s'..." % (f, dir))
for w in utils.walkFiles(dir, recurse=True, abs_paths=True, return_folders=False, pattern=f):
log.debug("File found at '%s'" % w)
@@ -373,9 +373,12 @@ def get_libpthread_version():
except ImportError:
@@ -361,9 +361,12 @@ def get_libpthread_version():
return '-'
else:
- LIBC = ctypes.CDLL(ctypes.util.find_library('c'), use_errno=True)
# LIBC = ctypes.CDLL(ctypes.util.find_library('c'), use_errno=True)
- LIBC = ctypes.CDLL(ctypes.util.find_library('c'),ctypes.DEFAULT_MODE,None, True)
- LIBC.gnu_get_libc_version.restype = ctypes.c_char_p
- return LIBC.gnu_get_libc_version()
+ if sys.platform.startswith('linux'):
+ LIBC = ctypes.CDLL(ctypes.util.find_library('c'), use_errno=True)
+ LIBC = ctypes.CDLL(ctypes.util.find_library('c'),ctypes.DEFAULT_MODE,None, True)
+ LIBC.gnu_get_libc_version.restype = ctypes.c_char_p
+ return LIBC.gnu_get_libc_version()
+ else:

View File

@ -0,0 +1,30 @@
$OpenBSD: patch-installer_pluginhandler_py,v 1.1 2013/03/08 06:51:46 ajacoutot Exp $
--- installer/pluginhandler.py.orig Fri Feb 22 17:52:29 2013
+++ installer/pluginhandler.py Fri Feb 22 17:54:29 2013
@@ -107,11 +107,11 @@ class PluginHandle(object):
ARCH = 'x86_%d' % BITNESS
if BITNESS == 64:
- SANELIBDIR = '/usr/lib64/sane'
- LIBDIR = '/usr/lib64'
+ SANELIBDIR = '${LOCALBASE}/lib/sane'
+ LIBDIR = '${LOCALBASE}/lib'
else:
- SANELIBDIR = '/usr/lib/sane'
- LIBDIR = '/usr/lib'
+ SANELIBDIR = '${LOCALBASE}/lib/sane'
+ LIBDIR = '${LOCALBASE}/lib'
copies = []
@@ -269,8 +269,8 @@ class PluginHandle(object):
def __setPluginConfFile(self):
home = sys_conf.get('dirs', 'home')
- if os.path.exists('/etc/hp/plugin.conf'):
- self.__plugin_conf_file = "file:///etc/hp/plugin.conf"
+ if os.path.exists('${SYSCONFDIR}/hp/plugin.conf'):
+ self.__plugin_conf_file = "file://${SYSCONFDIR}/hp/plugin.conf"
elif os.path.exists(os.path.join(home, 'plugin.conf')):
self.__plugin_conf_file = "file://" + os.path.join(home, 'plugin.conf')

View File

@ -1,9 +1,9 @@
$OpenBSD: patch-io_hpmud_musb_c,v 1.5 2012/12/10 16:00:12 ajacoutot Exp $
$OpenBSD: patch-io_hpmud_musb_c,v 1.6 2013/03/08 06:51:46 ajacoutot Exp $
Fix probing HP PS 8250 printer, from FreeBSD.
--- io/hpmud/musb.c.orig Tue Nov 20 10:55:09 2012
+++ io/hpmud/musb.c Mon Dec 10 16:43:14 2012
--- io/hpmud/musb.c.orig Wed Feb 13 17:38:44 2013
+++ io/hpmud/musb.c Fri Feb 22 15:05:18 2013
@@ -25,6 +25,7 @@
Author: Naga Samrat Chowdary Narla, Sarbeswar Meher
\*****************************************************************************/
@ -12,7 +12,7 @@ Fix probing HP PS 8250 printer, from FreeBSD.
#include "hpmud.h"
#include "hpmudi.h"
#include <dlfcn.h>
@@ -137,8 +138,12 @@ static int get_string_descriptor(libusb_device_handle
@@ -138,8 +139,12 @@ static int get_string_descriptor(libusb_device_handle
if (ret==0)
{

View File

@ -1,6 +1,6 @@
$OpenBSD: patch-prnt_cups_py,v 1.5 2012/09/11 10:52:16 ajacoutot Exp $
--- prnt/cups.py.orig Tue Sep 4 14:31:12 2012
+++ prnt/cups.py Tue Sep 11 08:05:33 2012
$OpenBSD: patch-prnt_cups_py,v 1.6 2013/03/08 06:51:46 ajacoutot Exp $
--- prnt/cups.py.orig Wed Feb 13 17:34:10 2013
+++ prnt/cups.py Fri Feb 22 15:17:48 2013
@@ -187,8 +187,8 @@ ppd_pat = re.compile(r'''.*hp-(.*?)(-.*)*\.ppd.*''', r
def getPPDPath(addtional_paths=None):
@ -16,8 +16,8 @@ $OpenBSD: patch-prnt_cups_py,v 1.5 2012/09/11 10:52:16 ajacoutot Exp $
def getAllowableMIMETypes():
"""
- Scan all /etc/cups/*.convs and /usr/share/cups/mime
+ Scan all ${SYSCONFDIR}/cups/*.convs and ${LOCALBASE}/share/cups/mime
- Scan all /etc/cups/*.convs and /usr/share/cups/mime
+ Scan all ${SYSCONFDIR}/cups/*.convs and ${LOCALBASE}/share/cups/mime
files for allowable file formats.
"""
paths = []

View File

@ -1,7 +1,7 @@
$OpenBSD: patch-prnt_hpcups_HPCupsFilter_cpp,v 1.8 2012/12/10 16:00:12 ajacoutot Exp $
--- prnt/hpcups/HPCupsFilter.cpp.orig Tue Nov 20 10:49:20 2012
+++ prnt/hpcups/HPCupsFilter.cpp Mon Dec 10 16:41:21 2012
@@ -859,7 +859,7 @@ void HPCupsFilter::getLogLevel ()
$OpenBSD: patch-prnt_hpcups_HPCupsFilter_cpp,v 1.9 2013/03/08 06:51:46 ajacoutot Exp $
--- prnt/hpcups/HPCupsFilter.cpp.orig Wed Feb 13 17:32:39 2013
+++ prnt/hpcups/HPCupsFilter.cpp Fri Feb 22 15:05:18 2013
@@ -868,7 +868,7 @@ void HPCupsFilter::getLogLevel ()
FILE *fp;
char str[258];
char *p;

View File

@ -1,7 +1,7 @@
$OpenBSD: patch-prnt_hpijs_hpcupsfax_cpp,v 1.3 2011/03/02 06:59:03 ajacoutot Exp $
--- prnt/hpijs/hpcupsfax.cpp.orig Wed Jan 19 06:15:28 2011
+++ prnt/hpijs/hpcupsfax.cpp Tue Feb 1 08:42:07 2011
@@ -92,7 +92,7 @@ static void GetLogLevel ()
$OpenBSD: patch-prnt_hpijs_hpcupsfax_cpp,v 1.4 2013/03/08 06:51:46 ajacoutot Exp $
--- prnt/hpijs/hpcupsfax.cpp.orig Wed Feb 13 17:34:10 2013
+++ prnt/hpijs/hpcupsfax.cpp Fri Feb 22 15:05:18 2013
@@ -93,7 +93,7 @@ static void GetLogLevel ()
FILE *fp;
char str[258];
char *p;

View File

@ -1,7 +1,7 @@
$OpenBSD: patch-prnt_hpijs_hpijs_cpp,v 1.1 2009/07/13 08:14:28 ajacoutot Exp $
--- prnt/hpijs/hpijs.cpp.orig Thu Jul 2 14:12:15 2009
+++ prnt/hpijs/hpijs.cpp Thu Jul 2 14:12:24 2009
@@ -76,7 +76,7 @@ void setLogLevel(UXServices *pSS)
$OpenBSD: patch-prnt_hpijs_hpijs_cpp,v 1.2 2013/03/08 06:51:46 ajacoutot Exp $
--- prnt/hpijs/hpijs.cpp.orig Wed Feb 13 17:34:10 2013
+++ prnt/hpijs/hpijs.cpp Fri Feb 22 15:05:18 2013
@@ -77,7 +77,7 @@ void setLogLevel(UXServices *pSS)
FILE *fp;
char str[258];
char *p;

View File

@ -1,12 +1,12 @@
$OpenBSD: patch-scan_py,v 1.7 2012/12/10 16:00:12 ajacoutot Exp $
--- scan.py.orig Tue Nov 20 10:55:15 2012
+++ scan.py Mon Dec 10 16:41:21 2012
@@ -1062,7 +1062,7 @@ try:
$OpenBSD: patch-scan_py,v 1.8 2013/03/08 06:51:46 ajacoutot Exp $
--- scan.py.orig Wed Feb 13 17:38:51 2013
+++ scan.py Fri Feb 22 15:05:18 2013
@@ -1088,7 +1088,7 @@ try:
if hp_print:
cmd = 'hp-print %s &' % output
else:
- cmd = "python ./print.py %s &" % output
+ cmd = "${MODPY_BIN} ./print.py %s &" % output
os.system(cmd)
os_utils.execute(cmd)

View File

@ -1,21 +1,12 @@
$OpenBSD: patch-setup_py,v 1.4 2012/09/11 10:52:16 ajacoutot Exp $
--- setup.py.orig Tue Sep 4 14:34:06 2012
+++ setup.py Tue Sep 11 08:05:33 2012
@@ -125,7 +125,7 @@ def restart_cups():
return '/etc/init.d/cupsys restart'
else:
- return 'killall -HUP cupsd'
+ return 'pkill -HUP cupsd'
mod = module.Module(__mod__, __title__, __version__, __doc__, USAGE,
@@ -879,7 +879,7 @@ else: # INTERACTIVE_MODE
$OpenBSD: patch-setup_py,v 1.5 2013/03/08 06:51:46 ajacoutot Exp $
--- setup.py.orig Wed Feb 13 17:38:51 2013
+++ setup.py Fri Feb 22 15:05:18 2013
@@ -868,7 +868,7 @@ else: # INTERACTIVE_MODE
if len(path) > 0:
cmd = 'hp-testpage %s' % param
else:
- cmd = 'python ./testpage.py %s' % param
+ cmd = '${MODPY_BIN} ./testpage.py %s' % param
log.debug(cmd)
os_utils.execute(cmd)

View File

@ -1,7 +1,7 @@
$OpenBSD: patch-ui4_devmgr5_py,v 1.7 2012/12/10 16:00:12 ajacoutot Exp $
--- ui4/devmgr5.py.orig Tue Nov 20 10:51:40 2012
+++ ui4/devmgr5.py Mon Dec 10 16:41:21 2012
@@ -1008,7 +1008,7 @@ class DevMgr5(QMainWindow, Ui_MainWindow):
$OpenBSD: patch-ui4_devmgr5_py,v 1.8 2013/03/08 06:51:46 ajacoutot Exp $
--- ui4/devmgr5.py.orig Wed Feb 13 17:35:05 2013
+++ ui4/devmgr5.py Fri Feb 22 15:05:19 2013
@@ -1014,7 +1014,7 @@ class DevMgr5(QMainWindow, Ui_MainWindow):
return
hplip_conf = ConfigParser.ConfigParser()
@ -10,7 +10,7 @@ $OpenBSD: patch-ui4_devmgr5_py,v 1.7 2012/12/10 16:00:12 ajacoutot Exp $
hplip_conf.readfp(fp)
fp.close()
@@ -2086,7 +2086,7 @@ class DevMgr5(QMainWindow, Ui_MainWindow):
@@ -2091,7 +2091,7 @@ class DevMgr5(QMainWindow, Ui_MainWindow):
if utils.which('hp-setup'):
cmd = 'hp-setup --gui'
else:
@ -18,8 +18,8 @@ $OpenBSD: patch-ui4_devmgr5_py,v 1.7 2012/12/10 16:00:12 ajacoutot Exp $
+ cmd = '${MODPY_BIN} ./setup.py --gui'
log.debug(cmd)
utils.run(cmd, log_output=True, password_func=None, timeout=1)
@@ -2098,7 +2098,7 @@ class DevMgr5(QMainWindow, Ui_MainWindow):
utils.run(cmd)
@@ -2103,7 +2103,7 @@ class DevMgr5(QMainWindow, Ui_MainWindow):
if utils.which('hp-setup'):
cmd = 'hp-setup --gui --remove'
else:

View File

@ -1,6 +1,6 @@
$OpenBSD: patch-ui4_nodevicesdialog_py,v 1.3 2011/03/02 06:59:03 ajacoutot Exp $
--- ui4/nodevicesdialog.py.orig Wed Jan 19 06:18:20 2011
+++ ui4/nodevicesdialog.py Tue Feb 1 08:42:07 2011
$OpenBSD: patch-ui4_nodevicesdialog_py,v 1.4 2013/03/08 06:51:46 ajacoutot Exp $
--- ui4/nodevicesdialog.py.orig Wed Feb 13 17:35:05 2013
+++ ui4/nodevicesdialog.py Fri Feb 22 15:05:19 2013
@@ -53,7 +53,7 @@ class NoDevicesDialog(QDialog, Ui_NoDevicesDialog_base
if utils.which('hp-setup'):
cmd = 'hp-setup -u'
@ -9,4 +9,4 @@ $OpenBSD: patch-ui4_nodevicesdialog_py,v 1.3 2011/03/02 06:59:03 ajacoutot Exp $
+ cmd = '${MODPY_BIN} ./setup.py -u'
log.debug(cmd)
utils.run(cmd, log_output=True, password_func=None, timeout=1)
utils.run(cmd)

View File

@ -1,7 +1,7 @@
$OpenBSD: patch-ui_devmgr4_py,v 1.5 2012/06/26 06:17:11 ajacoutot Exp $
--- ui/devmgr4.py.orig Mon Jun 18 12:42:07 2012
+++ ui/devmgr4.py Tue Jun 26 07:06:29 2012
@@ -2811,7 +2811,7 @@ class DevMgr4(DevMgr4_base):
$OpenBSD: patch-ui_devmgr4_py,v 1.6 2013/03/08 06:51:46 ajacoutot Exp $
--- ui/devmgr4.py.orig Wed Feb 13 17:35:09 2013
+++ ui/devmgr4.py Fri Feb 22 15:05:19 2013
@@ -2810,7 +2810,7 @@ class DevMgr4(DevMgr4_base):
if utils.which('hp-setup'):
cmd = 'hp-setup -u'
else:
@ -9,4 +9,4 @@ $OpenBSD: patch-ui_devmgr4_py,v 1.5 2012/06/26 06:17:11 ajacoutot Exp $
+ cmd = '${MODPY_BIN} ./setup.py --gui'
log.debug(cmd)
utils.run(cmd, log_output=True, password_func=None, timeout=1)
utils.run(cmd)

View File

@ -1,6 +1,6 @@
$OpenBSD: patch-ui_nodevicesform_py,v 1.3 2011/03/02 06:59:03 ajacoutot Exp $
--- ui/nodevicesform.py.orig Wed Jan 19 06:18:26 2011
+++ ui/nodevicesform.py Tue Feb 1 08:42:07 2011
$OpenBSD: patch-ui_nodevicesform_py,v 1.4 2013/03/08 06:51:46 ajacoutot Exp $
--- ui/nodevicesform.py.orig Wed Feb 13 17:35:09 2013
+++ ui/nodevicesform.py Fri Feb 22 15:05:19 2013
@@ -56,7 +56,7 @@ class NoDevicesForm(NoDevicesForm_base):
if utils.which('hp-setup'):
cmd = 'hp-setup -u'
@ -9,4 +9,4 @@ $OpenBSD: patch-ui_nodevicesform_py,v 1.3 2011/03/02 06:59:03 ajacoutot Exp $
+ cmd = '${MODPY_BIN} ./setup.py -u'
log.debug(cmd)
utils.run(cmd, log_output=True, password_func=None, timeout=1)
utils.run(cmd)

View File

@ -1,12 +0,0 @@
$OpenBSD: patch-ui_setupform_py,v 1.1 2009/07/13 08:14:29 ajacoutot Exp $
--- ui/setupform.py.orig Thu Jul 2 14:38:04 2009
+++ ui/setupform.py Thu Jul 2 14:38:17 2009
@@ -57,7 +57,7 @@ def restart_cups():
return '/etc/init.d/cupsys restart'
else:
- return 'killall -HUP cupsd'
+ return 'pkill -HUP cupsd'
class DeviceListViewItem(QListViewItem):

View File

@ -1,7 +1,6 @@
@comment $OpenBSD: PLIST-gui,v 1.9 2012/12/10 16:00:12 ajacoutot Exp $
@comment $OpenBSD: PLIST-gui,v 1.10 2013/03/08 06:51:46 ajacoutot Exp $
@conflict hplip-<3.11.3p0
bin/hp-align
bin/hp-check-plugin
bin/hp-colorcal
bin/hp-devicesettings
bin/hp-diagnose_plugin

View File

@ -1,11 +1,8 @@
@comment $OpenBSD: PLIST-hpijs,v 1.22 2013/01/04 18:21:54 ajacoutot Exp $
@comment $OpenBSD: PLIST-hpijs,v 1.23 2013/03/08 06:51:46 ajacoutot Exp $
@conflict hplip-libs-<=3.9.8
@conflict hpcups-<=3.2.11
@pkgpath print/hpijs
@bin bin/hpijs
lib/python${MODPY_VERSION}/
lib/python${MODPY_VERSION}/site-packages/
lib/sane/
libexec/cups/filter/foomatic-rip-hplip
@bin libexec/cups/filter/hplipjs
share/cups/drv/hp/hpijs.drv
@ -186,7 +183,6 @@ share/foomatic/db/source/PPD/HP/hp-designjet_t770_postscript-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-designjet_t770ps_24in-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-designjet_t790ps_24in-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-designjet_t790ps_44in-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-designjet_t800_t2000_premium-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-designjet_z6100ps_42in_photo-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-designjet_z6100ps_60in_photo-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-designjet_z6200_42in_photo-ps.ppd.gz
@ -457,10 +453,10 @@ share/foomatic/db/source/PPD/HP/hp-laserjet_3390-hpijs-pcl3.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_3390-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_3392-hpijs.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_4-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_400_m401dne-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_4000_series-hpijs-pcl3.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_4000_series-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_400_m401-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_400_m401d-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_400_mfp_m425-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_4050_series-hpijs-pcl3.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_4050_series-ps.ppd.gz
@ -499,7 +495,6 @@ share/foomatic/db/source/PPD/HP/hp-laserjet_5000_series-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_500_color_m551-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_500_color_mfp_m570-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_500_color_mfp_m575-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_500_mfp_m521-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_500_mfp_m525-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_5100_series-hpijs-pcl3.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_5100_series-ps.ppd.gz
@ -603,8 +598,6 @@ share/foomatic/db/source/PPD/HP/hp-laserjet_m9050_mfp-hpijs-pcl3.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_m9050_mfp-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_m9059_mfp-hpijs-pcl3.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_m9059_mfp-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_mfp_m521-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_mfp_m725-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_p1005-hpijs.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_p1006-hpijs.ppd.gz
share/foomatic/db/source/PPD/HP/hp-laserjet_p1007-hpijs.ppd.gz
@ -731,6 +724,7 @@ share/foomatic/db/source/PPD/HP/hp-officejet_6700-hpijs.ppd.gz
share/foomatic/db/source/PPD/HP/hp-officejet_7000_e809a-hpijs.ppd.gz
share/foomatic/db/source/PPD/HP/hp-officejet_7000_e809a_series-hpijs.ppd.gz
share/foomatic/db/source/PPD/HP/hp-officejet_7100_series-hpijs.ppd.gz
share/foomatic/db/source/PPD/HP/hp-officejet_7110_series-hpijs.ppd.gz
share/foomatic/db/source/PPD/HP/hp-officejet_7200_series-hpijs.ppd.gz
share/foomatic/db/source/PPD/HP/hp-officejet_7300_series-hpijs.ppd.gz
share/foomatic/db/source/PPD/HP/hp-officejet_7400_series-hpijs.ppd.gz
@ -759,8 +753,6 @@ share/foomatic/db/source/PPD/HP/hp-officejet_k80xi-hpijs.ppd.gz
share/foomatic/db/source/PPD/HP/hp-officejet_lx-hpijs.ppd.gz
share/foomatic/db/source/PPD/HP/hp-officejet_pro_1150c-hpijs.ppd.gz
share/foomatic/db/source/PPD/HP/hp-officejet_pro_1170c_series-hpijs.ppd.gz
share/foomatic/db/source/PPD/HP/hp-officejet_pro_251dw_printer-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-officejet_pro_276dw_mfp-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-officejet_pro_451_series-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-officejet_pro_476_576_series-ps.ppd.gz
share/foomatic/db/source/PPD/HP/hp-officejet_pro_551_series-ps.ppd.gz

View File

@ -1,4 +1,4 @@
@comment $OpenBSD: PLIST-main,v 1.18 2013/01/20 08:44:16 ajacoutot Exp $
@comment $OpenBSD: PLIST-main,v 1.19 2013/03/08 06:51:46 ajacoutot Exp $
@conflict hplip-docs-*
@conflict hplip-gui-<3.11.3p0
@extraunexec rm -rf /var/log/hp/tmp/*
@ -7,6 +7,7 @@ bin/hp-check
bin/hp-clean
bin/hp-config_usb_printer
bin/hp-diagnose_queues
bin/hp-doctor
bin/hp-logcapture
bin/hp-makeuri
@bin bin/hp-mkuri
@ -122,6 +123,10 @@ share/hplip/base/models.py
share/hplip/base/models.pyc
share/hplip/base/module.py
share/hplip/base/module.pyc
share/hplip/base/os_utils.py
share/hplip/base/os_utils.pyc
share/hplip/base/password.py
share/hplip/base/password.pyc
share/hplip/base/pexpect.py
share/hplip/base/pexpect.pyc
share/hplip/base/pkit.py
@ -130,8 +135,12 @@ share/hplip/base/pml.py
share/hplip/base/pml.pyc
share/hplip/base/queues.py
share/hplip/base/queues.pyc
share/hplip/base/services.py
share/hplip/base/services.pyc
share/hplip/base/slp.py
share/hplip/base/slp.pyc
share/hplip/base/smart_install.py
share/hplip/base/smart_install.pyc
share/hplip/base/status.py
share/hplip/base/status.pyc
share/hplip/base/strings.py
@ -206,6 +215,8 @@ share/hplip/diagnose_plugin.py
share/hplip/diagnose_plugin.pyc
share/hplip/diagnose_queues.py
share/hplip/diagnose_queues.pyc
share/hplip/doctor.py
share/hplip/doctor.pyc
share/hplip/fab.py
share/hplip/fab.pyc
share/hplip/fax/
@ -248,6 +259,8 @@ share/hplip/installer/core_install.pyc
share/hplip/installer/dcheck.py
share/hplip/installer/dcheck.pyc
share/hplip/installer/distros.dat
share/hplip/installer/pluginhandler.py
share/hplip/installer/pluginhandler.pyc
share/hplip/levels.py
share/hplip/levels.pyc
share/hplip/linefeedcal.py

View File

@ -1,10 +1,11 @@
$OpenBSD: README-hpcups,v 1.2 2012/08/04 14:55:37 ajacoutot Exp $
$OpenBSD: README-hpcups,v 1.3 2013/03/08 06:51:46 ajacoutot Exp $
+-----------------------------------------------------------------------
| Running ${FULLPKGNAME} on OpenBSD
+-----------------------------------------------------------------------
To add a CUPS printer, use the `hp-makeuri' command.
To add a CUPS printer, use the `hp-makeuri' command from the "hplip"
package.
e.g. for a network printer:
$ hp-makeuri 192.168.10.100
<...>
--- base/queues.py.orig Wed Feb 13 17:38:51 2013
+++ base/queues.py Fri Feb 22 15:16:08 2013
@@ -66,7 +66,7 @@ class DetectedDevice:
##### METHODS #####
@ -10,7 +10,7 @@ $OpenBSD: patch-base_queues_py,v 1.1 2013/01/26 12:25:54 ajacoutot Exp $
def check_user_groups():
result = False
sts,output = utils.run('groups')
@@ -78,14 +78,14 @@ def check_user_groups():
@@ -78,21 +78,21 @@ def check_user_groups():
grp_list= output.split(' ')
cnt = 0
while cnt < len(grp_list) :
@ -19,35 +19,43 @@ $OpenBSD: patch-base_queues_py,v 1.1 2013/01/26 12:25:54 ajacoutot Exp $
result = True
break
cnt += 1
return result
# This function adds the groups ('lp') to user
def add_group(core):
# This function adds the groups ('lp') to user
def add_group(core, mode, passwordObj):
result = False
add_user_to_group = core.get_distro_ver_data('add_user_to_group', '')
@@ -111,7 +111,7 @@ def add_group(core):
cmd =su_sudo % usermod
if add_user_to_group:
usermod = os.path.join(utils.which("usermod"), "usermod") + " %s %s" % (add_user_to_group, prop.username)
else:
- usermod = os.path.join(utils.which("usermod"), "usermod") + " %s -a %s" % ("-Glp", prop.username)
+ usermod = os.path.join(utils.which("usermod"), "usermod") + " %s -a %s" % ("-G _cups", prop.username)
if passwordObj == None:
passwordObj = password.Password(mode)
@@ -100,7 +100,7 @@ def add_group(core, mode, passwordObj):
cmd =passwordObj.getAuthCmd() % usermod
log.info("cmd = %s" %cmd)
# sts, output = utils.run(cmd, True, password_f, -1,True,cmd)
- sts, output = utils.run(cmd, True, password_f, 1, True, "Please enter root/superuser password to add 'lp' group")
+ sts, output = utils.run(cmd, True, password_f, 1, True, "Please enter root/superuser password to add '_cups' group")
- pswd_msg = "Enter root/superuser password to add 'lp' group"
+ pswd_msg = "Enter root/superuser password to add '_cups' group"
sts, output = utils.run(cmd, passwordObj, pswd_msg)
if sts == 0:
result = True
@@ -364,7 +364,7 @@ def main_function(mode = GUI_MODE, ui_toolkit= UI_TOOL
@@ -355,7 +355,7 @@ def main_function(passwordObj = None, mode = GUI_MODE,
core.init()
if add_group(core) is False:
if add_group(core, mode, passwordObj) is False:
Error_Found = True
- log.error("Failed to add lp group to user[%s]. Manually add 'lp' group to usergroups. And reboot system."%prop.username)
+ log.error("Failed to add _cups group to user[%s]. Manually add '_cups' group to usergroups. And reboot system."%prop.username)
else:
log.info("Groups added successfully and reboot is required. Please reboot system to take effect.")
mapofDevices = parseQueues()
@@ -411,7 +411,7 @@ def main_function(mode = GUI_MODE, ui_toolkit= UI_TOOL
mapofDevices = parseQueues(mode)
@@ -406,7 +406,7 @@ def main_function(passwordObj = None, mode = GUI_MODE,
core.init()
if add_group(core) is False:
if add_group(core, mode, passwordObj) is False:
Error_Found = True
- dialog.showMessage("User must be part of 'lp' group.\nManually add 'lp' group to '%s' user. " %prop.username)
+ dialog.showMessage("User must be part of '_cups' group.\nManually add '_cups' group to '%s' user. " %prop.username)

View File

@ -0,0 +1,36 @@
$OpenBSD: patch-base_services_py,v 1.1 2013/03/08 06:51:46 ajacoutot Exp $
@@ -78,21 +78,21 @@ def check_user_groups():
cnt += 1
return result
-# This function adds the groups ('lp') to user
+# This function adds the groups ('_cups') to user
def add_group(core):
@@ -78,21 +78,21 @@ def check_user_groups():
def add_group(core):
-# This function adds the groups ('lp') to user
+# This function adds the groups ('_cups') to user
def add_group(core, mode, passwordObj):
result = False